========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/python-dracclient.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

python-dracclient
=================

Library for managing machines with Dell iDRAC cards.

* Free software: Apache license
* Documentation: https://docs.openstack.org/python-dracclient/latest
* Source: http://opendev.org/openstack/python-dracclient
* Bugs: https://bugs.launchpad.net/python-dracclient
